==> trustedqsl_1.11.orig.tar.gz: TrustedQSL-1.11/tqslcert_prefs.h <==
/***************************************************************************
                          tqslcert_prefs.h  -  description
                             -------------------
    begin                : Mon Jul 1 2002
    copyright            : (C) 2002 by ARRL
    author               : Jon Bloom
    email                : jbloom@arrl.org
    revision             : $Id: tqslcert_prefs.h,v 1.3 2005/02/18 20:28:30 ke3z Exp $
 ***************************************************************************/

#ifndef __TQSLCERT_PREFS_H
#define __TQSLCERT_PREFS_H

#ifdef HAVE_CONFIG_H
#include "sysconfig.h"
#endif

#include "wx/wxprec.h"
#include "wx/object.h"
#include "wx/config.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#ifndef WX_PRECOMP
	#include "wx/wx.h"
#endif

#include "wx/dialog.h"
#include "wx/checkbox.h"
#include "tqslcertctrls.h"

#define DEFAULT_CABRILLO_FILES "log cbr"
#define DEFAULT_ADIF_FILES "adi"

class KeyPrefs : public wxPanel {
public:
	KeyPrefs(wxWindow *parent);
	virtual bool TransferDataFromWindow();
private:
	wxCheckBox *root_cb, *ca_cb, *user_cb;
};

class FilePrefs : public wxPanel {
public:
	FilePrefs(wxWindow *parent);
	virtual bool TransferDataFromWindow();
private:
	wxTextCtrl *cabrillo, *adif;
};

class Preferences : public wxDialog {
public:
	Preferences(wxWindow *parent);
	void OnOK(wxCommandEvent &);
	void OnCancel(wxCommandEvent &) { Close(TRUE); }
	DECLARE_EVENT_TABLE()
private:
	KeyPrefs *keyprefs;
	FilePrefs *fileprefs;
};

#endif	// __TQSLCERT_PREFS_H

==> trustedqsl_1.13.orig.tar.gz: TrustedQSL-1.13/tqslcert_prefs.h <==
/***************************************************************************
                          tqslcert_prefs.h  -  description
                             -------------------
    begin                : Mon Jul 1 2002
    copyright            : (C) 2002 by ARRL
    author               : Jon Bloom
    email                : jbloom@arrl.org
    revision             : $Id: tqslcert_prefs.h,v 1.4 2010/03/24 22:54:34 k1mu Exp $
 ***************************************************************************/

#ifndef __TQSLCERT_PREFS_H
#define __TQSLCERT_PREFS_H

#ifdef HAVE_CONFIG_H
#include "sysconfig.h"
#endif

#include "wx/wxprec.h"
#include "wx/object.h"
#include "wx/config.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#ifndef WX_PRECOMP
	#include "wx/wx.h"
#endif

#include "wx/dialog.h"
#include "wx/checkbox.h"
#include "tqslcertctrls.h"

#define DEFAULT_CABRILLO_FILES "log cbr"
#define DEFAULT_ADIF_FILES "adi"

class KeyPrefs : public wxPanel {
public:
	KeyPrefs(wxWindow *parent);
	virtual bool TransferDataFromWindow();
private:
	wxCheckBox *root_cb, *ca_cb, *user_cb;
};

class CertPrefs : public wxPanel {
public:
	CertPrefs(wxWindow *parent);
	virtual bool TransferDataFromWindow();
private:
	wxCheckBox *showSuperceded_cb;
	wxCheckBox *showExpired_cb;
};

class Preferences : public wxDialog {
public:
	Preferences(wxWindow *parent);
	void OnOK(wxCommandEvent &);
	void OnCancel(wxCommandEvent &) { Close(TRUE); }
	DECLARE_EVENT_TABLE()
private:
	KeyPrefs *keyprefs;
	CertPrefs *certprefs;
};

#endif	// __TQSLCERT_PREFS_H
